[Compare the full difference.](https://github.com/callowayproject/bump-my-version/compare/0.28.0...0.28.1)

### Fixes

- Fix format arg help text for show command. [cf65ec2](https://github.com/callowayproject/bump-my-version/commit/cf65ec27ae68e2bf5b397591ff00fc86d2eab21f)
    
### Other

- [pre-commit.ci] pre-commit autoupdate. [9fb0347](https://github.com/callowayproject/bump-my-version/commit/9fb03472d5cfa16281e2e3f049b660dc503eb167)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.6.9 → v0.7.1](https://github.com/astral-sh/ruff-pre-commit/compare/v0.6.9...v0.7.1)

- Output hooks scripts by default. [0a042aa](https://github.com/callowayproject/bump-my-version/commit/0a042aaa8fabd5c64ea5ffd153c959ccdacf80c6)
    
- Skip scm tests if the command is not installed. [2e68517](https://github.com/callowayproject/bump-my-version/commit/2e68517f890e1da7520486baf102c559ed2f40ea)
    
